@@ -16,6 +16,8 @@ class Flask():
         Flask.apply(self)
 
     def apply(self):
-        @self.app.route(self.route)
-        def nodecdnjsurl():
-            return "Works!"
\ No newline at end of file
+        if self.route.startswith('/'):
+            @self.app.route(self.route)
+            def nodecdnjsurl():
+                return "Works!"
+        else: print('[Flask] You must provide a leading slash before your route.')
\ No newline at end of file
